# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.container_info import ContainerInfo  # noqa: F401,E501
from kps_api.models.reference import Reference  # noqa: F401,E501


class Pod(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'annotations': 'dict(str, str)',
        'app_label': 'bool',
        'containers': 'list[ContainerInfo]',
        'created_at': 'str',
        'created_by': 'list[Reference]',
        'istio_containers': 'list[ContainerInfo]',
        'istio_init_containers': 'list[ContainerInfo]',
        'labels': 'dict(str, str)',
        'name': 'str',
        'status': 'str',
        'version_label': 'bool'
    }

    attribute_map = {
        'annotations': 'annotations',
        'app_label': 'appLabel',
        'containers': 'containers',
        'created_at': 'createdAt',
        'created_by': 'createdBy',
        'istio_containers': 'istioContainers',
        'istio_init_containers': 'istioInitContainers',
        'labels': 'labels',
        'name': 'name',
        'status': 'status',
        'version_label': 'versionLabel'
    }

    def __init__(self, annotations=None, app_label=None, containers=None, created_at=None, created_by=None, istio_containers=None, istio_init_containers=None, labels=None, name=None, status=None, version_label=None):  # noqa: E501
        """Pod - a model defined in Swagger"""  # noqa: E501
        self._annotations = None
        self._app_label = None
        self._containers = None
        self._created_at = None
        self._created_by = None
        self._istio_containers = None
        self._istio_init_containers = None
        self._labels = None
        self._name = None
        self._status = None
        self._version_label = None
        self.discriminator = None
        if annotations is not None:
            self.annotations = annotations
        if app_label is not None:
            self.app_label = app_label
        if containers is not None:
            self.containers = containers
        if created_at is not None:
            self.created_at = created_at
        if created_by is not None:
            self.created_by = created_by
        if istio_containers is not None:
            self.istio_containers = istio_containers
        if istio_init_containers is not None:
            self.istio_init_containers = istio_init_containers
        if labels is not None:
            self.labels = labels
        if name is not None:
            self.name = name
        if status is not None:
            self.status = status
        if version_label is not None:
            self.version_label = version_label

    @property
    def annotations(self):
        """Gets the annotations of this Pod.  # noqa: E501


        :return: The annotations of this Pod.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._annotations

    @annotations.setter
    def annotations(self, annotations):
        """Sets the annotations of this Pod.


        :param annotations: The annotations of this Pod.  # noqa: E501
        :type: dict(str, str)
        """

        self._annotations = annotations

    @property
    def app_label(self):
        """Gets the app_label of this Pod.  # noqa: E501


        :return: The app_label of this Pod.  # noqa: E501
        :rtype: bool
        """
        return self._app_label

    @app_label.setter
    def app_label(self, app_label):
        """Sets the app_label of this Pod.


        :param app_label: The app_label of this Pod.  # noqa: E501
        :type: bool
        """

        self._app_label = app_label

    @property
    def containers(self):
        """Gets the containers of this Pod.  # noqa: E501


        :return: The containers of this Pod.  # noqa: E501
        :rtype: list[ContainerInfo]
        """
        return self._containers

    @containers.setter
    def containers(self, containers):
        """Sets the containers of this Pod.


        :param containers: The containers of this Pod.  # noqa: E501
        :type: list[ContainerInfo]
        """

        self._containers = containers

    @property
    def created_at(self):
        """Gets the created_at of this Pod.  # noqa: E501


        :return: The created_at of this Pod.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Pod.


        :param created_at: The created_at of this Pod.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def created_by(self):
        """Gets the created_by of this Pod.  # noqa: E501


        :return: The created_by of this Pod.  # noqa: E501
        :rtype: list[Reference]
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Pod.


        :param created_by: The created_by of this Pod.  # noqa: E501
        :type: list[Reference]
        """

        self._created_by = created_by

    @property
    def istio_containers(self):
        """Gets the istio_containers of this Pod.  # noqa: E501


        :return: The istio_containers of this Pod.  # noqa: E501
        :rtype: list[ContainerInfo]
        """
        return self._istio_containers

    @istio_containers.setter
    def istio_containers(self, istio_containers):
        """Sets the istio_containers of this Pod.


        :param istio_containers: The istio_containers of this Pod.  # noqa: E501
        :type: list[ContainerInfo]
        """

        self._istio_containers = istio_containers

    @property
    def istio_init_containers(self):
        """Gets the istio_init_containers of this Pod.  # noqa: E501


        :return: The istio_init_containers of this Pod.  # noqa: E501
        :rtype: list[ContainerInfo]
        """
        return self._istio_init_containers

    @istio_init_containers.setter
    def istio_init_containers(self, istio_init_containers):
        """Sets the istio_init_containers of this Pod.


        :param istio_init_containers: The istio_init_containers of this Pod.  # noqa: E501
        :type: list[ContainerInfo]
        """

        self._istio_init_containers = istio_init_containers

    @property
    def labels(self):
        """Gets the labels of this Pod.  # noqa: E501


        :return: The labels of this Pod.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this Pod.


        :param labels: The labels of this Pod.  # noqa: E501
        :type: dict(str, str)
        """

        self._labels = labels

    @property
    def name(self):
        """Gets the name of this Pod.  # noqa: E501


        :return: The name of this Pod.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Pod.


        :param name: The name of this Pod.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def status(self):
        """Gets the status of this Pod.  # noqa: E501


        :return: The status of this Pod.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Pod.


        :param status: The status of this Pod.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def version_label(self):
        """Gets the version_label of this Pod.  # noqa: E501


        :return: The version_label of this Pod.  # noqa: E501
        :rtype: bool
        """
        return self._version_label

    @version_label.setter
    def version_label(self, version_label):
        """Sets the version_label of this Pod.


        :param version_label: The version_label of this Pod.  # noqa: E501
        :type: bool
        """

        self._version_label = version_label

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Pod, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Pod):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class DataSourceFieldInfoV2(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'topic': 'str'
    }

    attribute_map = {
        'name': 'name',
        'topic': 'topic'
    }

    def __init__(self, name=None, topic=None):  # noqa: E501
        """DataSourceFieldInfoV2 - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._topic = None
        self.discriminator = None
        self.name = name
        self.topic = topic

    @property
    def name(self):
        """Gets the name of this DataSourceFieldInfoV2.  # noqa: E501

        Name of the field. A unique name within the the data source.  # noqa: E501

        :return: The name of this DataSourceFieldInfoV2.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DataSourceFieldInfoV2.

        Name of the field. A unique name within the the data source.  # noqa: E501

        :param name: The name of this DataSourceFieldInfoV2.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def topic(self):
        """Gets the topic of this DataSourceFieldInfoV2.  # noqa: E501

        topic for the field The topic specified depends on the protocol in the data source. Specify the mqqtTopic for the MQTT protocol. For the RTSP protocol, the topic is the server endpoint or named protocol stream in the RSTP URL.  # noqa: E501

        :return: The topic of this DataSourceFieldInfoV2.  # noqa: E501
        :rtype: str
        """
        return self._topic

    @topic.setter
    def topic(self, topic):
        """Sets the topic of this DataSourceFieldInfoV2.

        topic for the field The topic specified depends on the protocol in the data source. Specify the mqqtTopic for the MQTT protocol. For the RTSP protocol, the topic is the server endpoint or named protocol stream in the RSTP URL.  # noqa: E501

        :param topic: The topic of this DataSourceFieldInfoV2.  # noqa: E501
        :type: str
        """
        if topic is None:
            raise ValueError("Invalid value for `topic`, must not be `None`")  # noqa: E501

        self._topic = topic

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DataSourceFieldInfoV2, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DataSourceFieldInfoV2):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class RetentionInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'limit': 'int',
        'type': 'str'
    }

    attribute_map = {
        'limit': 'limit',
        'type': 'type'
    }

    def __init__(self, limit=None, type=None):  # noqa: E501
        """RetentionInfo - a model defined in Swagger"""  # noqa: E501
        self._limit = None
        self._type = None
        self.discriminator = None
        self.limit = limit
        self.type = type

    @property
    def limit(self):
        """Gets the limit of this RetentionInfo.  # noqa: E501


        :return: The limit of this RetentionInfo.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this RetentionInfo.


        :param limit: The limit of this RetentionInfo.  # noqa: E501
        :type: int
        """
        if limit is None:
            raise ValueError("Invalid value for `limit`, must not be `None`")  # noqa: E501

        self._limit = limit

    @property
    def type(self):
        """Gets the type of this RetentionInfo.  # noqa: E501

        Retention type can be Time or Size. For Time based retention, limit is in seconds and specifies how long the data should be retained. For Size based retention, limit is in GB and specifies up to the maximum capacity/amount of data to retain.  # noqa: E501

        :return: The type of this RetentionInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this RetentionInfo.

        Retention type can be Time or Size. For Time based retention, limit is in seconds and specifies how long the data should be retained. For Size based retention, limit is in GB and specifies up to the maximum capacity/amount of data to retain.  # noqa: E501

        :param type: The type of this RetentionInfo.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["Time", "Size"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RetentionInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RetentionInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.key_value import KeyValue  # noqa: F401,E501
from kps_api.models.log import Log  # noqa: F401,E501
from kps_api.models.process import Process  # noqa: F401,E501
from kps_api.models.process_id import ProcessID  # noqa: F401,E501
from kps_api.models.reference import Reference  # noqa: F401,E501
from kps_api.models.span_id import SpanID  # noqa: F401,E501
from kps_api.models.trace_id import TraceID  # noqa: F401,E501


class Span(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'duration': 'int',
        'flags': 'int',
        'logs': 'list[Log]',
        'operation_name': 'str',
        'parent_span_id': 'SpanID',
        'process': 'Process',
        'process_id': 'ProcessID',
        'references': 'list[Reference]',
        'span_id': 'SpanID',
        'start_time': 'int',
        'tags': 'list[KeyValue]',
        'trace_id': 'TraceID',
        'trace_size': 'int',
        'warnings': 'list[str]'
    }

    attribute_map = {
        'duration': 'duration',
        'flags': 'flags',
        'logs': 'logs',
        'operation_name': 'operationName',
        'parent_span_id': 'parentSpanID',
        'process': 'process',
        'process_id': 'processID',
        'references': 'references',
        'span_id': 'spanID',
        'start_time': 'startTime',
        'tags': 'tags',
        'trace_id': 'traceID',
        'trace_size': 'traceSize',
        'warnings': 'warnings'
    }

    def __init__(self, duration=None, flags=None, logs=None, operation_name=None, parent_span_id=None, process=None, process_id=None, references=None, span_id=None, start_time=None, tags=None, trace_id=None, trace_size=None, warnings=None):  # noqa: E501
        """Span - a model defined in Swagger"""  # noqa: E501
        self._duration = None
        self._flags = None
        self._logs = None
        self._operation_name = None
        self._parent_span_id = None
        self._process = None
        self._process_id = None
        self._references = None
        self._span_id = None
        self._start_time = None
        self._tags = None
        self._trace_id = None
        self._trace_size = None
        self._warnings = None
        self.discriminator = None
        if duration is not None:
            self.duration = duration
        if flags is not None:
            self.flags = flags
        if logs is not None:
            self.logs = logs
        if operation_name is not None:
            self.operation_name = operation_name
        if parent_span_id is not None:
            self.parent_span_id = parent_span_id
        if process is not None:
            self.process = process
        if process_id is not None:
            self.process_id = process_id
        if references is not None:
            self.references = references
        if span_id is not None:
            self.span_id = span_id
        if start_time is not None:
            self.start_time = start_time
        if tags is not None:
            self.tags = tags
        if trace_id is not None:
            self.trace_id = trace_id
        if trace_size is not None:
            self.trace_size = trace_size
        if warnings is not None:
            self.warnings = warnings

    @property
    def duration(self):
        """Gets the duration of this Span.  # noqa: E501


        :return: The duration of this Span.  # noqa: E501
        :rtype: int
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this Span.


        :param duration: The duration of this Span.  # noqa: E501
        :type: int
        """

        self._duration = duration

    @property
    def flags(self):
        """Gets the flags of this Span.  # noqa: E501


        :return: The flags of this Span.  # noqa: E501
        :rtype: int
        """
        return self._flags

    @flags.setter
    def flags(self, flags):
        """Sets the flags of this Span.


        :param flags: The flags of this Span.  # noqa: E501
        :type: int
        """

        self._flags = flags

    @property
    def logs(self):
        """Gets the logs of this Span.  # noqa: E501


        :return: The logs of this Span.  # noqa: E501
        :rtype: list[Log]
        """
        return self._logs

    @logs.setter
    def logs(self, logs):
        """Sets the logs of this Span.


        :param logs: The logs of this Span.  # noqa: E501
        :type: list[Log]
        """

        self._logs = logs

    @property
    def operation_name(self):
        """Gets the operation_name of this Span.  # noqa: E501


        :return: The operation_name of this Span.  # noqa: E501
        :rtype: str
        """
        return self._operation_name

    @operation_name.setter
    def operation_name(self, operation_name):
        """Sets the operation_name of this Span.


        :param operation_name: The operation_name of this Span.  # noqa: E501
        :type: str
        """

        self._operation_name = operation_name

    @property
    def parent_span_id(self):
        """Gets the parent_span_id of this Span.  # noqa: E501


        :return: The parent_span_id of this Span.  # noqa: E501
        :rtype: SpanID
        """
        return self._parent_span_id

    @parent_span_id.setter
    def parent_span_id(self, parent_span_id):
        """Sets the parent_span_id of this Span.


        :param parent_span_id: The parent_span_id of this Span.  # noqa: E501
        :type: SpanID
        """

        self._parent_span_id = parent_span_id

    @property
    def process(self):
        """Gets the process of this Span.  # noqa: E501


        :return: The process of this Span.  # noqa: E501
        :rtype: Process
        """
        return self._process

    @process.setter
    def process(self, process):
        """Sets the process of this Span.


        :param process: The process of this Span.  # noqa: E501
        :type: Process
        """

        self._process = process

    @property
    def process_id(self):
        """Gets the process_id of this Span.  # noqa: E501


        :return: The process_id of this Span.  # noqa: E501
        :rtype: ProcessID
        """
        return self._process_id

    @process_id.setter
    def process_id(self, process_id):
        """Sets the process_id of this Span.


        :param process_id: The process_id of this Span.  # noqa: E501
        :type: ProcessID
        """

        self._process_id = process_id

    @property
    def references(self):
        """Gets the references of this Span.  # noqa: E501


        :return: The references of this Span.  # noqa: E501
        :rtype: list[Reference]
        """
        return self._references

    @references.setter
    def references(self, references):
        """Sets the references of this Span.


        :param references: The references of this Span.  # noqa: E501
        :type: list[Reference]
        """

        self._references = references

    @property
    def span_id(self):
        """Gets the span_id of this Span.  # noqa: E501


        :return: The span_id of this Span.  # noqa: E501
        :rtype: SpanID
        """
        return self._span_id

    @span_id.setter
    def span_id(self, span_id):
        """Sets the span_id of this Span.


        :param span_id: The span_id of this Span.  # noqa: E501
        :type: SpanID
        """

        self._span_id = span_id

    @property
    def start_time(self):
        """Gets the start_time of this Span.  # noqa: E501


        :return: The start_time of this Span.  # noqa: E501
        :rtype: int
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this Span.


        :param start_time: The start_time of this Span.  # noqa: E501
        :type: int
        """

        self._start_time = start_time

    @property
    def tags(self):
        """Gets the tags of this Span.  # noqa: E501


        :return: The tags of this Span.  # noqa: E501
        :rtype: list[KeyValue]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this Span.


        :param tags: The tags of this Span.  # noqa: E501
        :type: list[KeyValue]
        """

        self._tags = tags

    @property
    def trace_id(self):
        """Gets the trace_id of this Span.  # noqa: E501


        :return: The trace_id of this Span.  # noqa: E501
        :rtype: TraceID
        """
        return self._trace_id

    @trace_id.setter
    def trace_id(self, trace_id):
        """Sets the trace_id of this Span.


        :param trace_id: The trace_id of this Span.  # noqa: E501
        :type: TraceID
        """

        self._trace_id = trace_id

    @property
    def trace_size(self):
        """Gets the trace_size of this Span.  # noqa: E501


        :return: The trace_size of this Span.  # noqa: E501
        :rtype: int
        """
        return self._trace_size

    @trace_size.setter
    def trace_size(self, trace_size):
        """Sets the trace_size of this Span.


        :param trace_size: The trace_size of this Span.  # noqa: E501
        :type: int
        """

        self._trace_size = trace_size

    @property
    def warnings(self):
        """Gets the warnings of this Span.  # noqa: E501


        :return: The warnings of this Span.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this Span.


        :param warnings: The warnings of this Span.  # noqa: E501
        :type: list[str]
        """

        self._warnings = warnings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Span, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Span):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.data_source_api import DataSourceApi  # noqa: E501
from kps_api.rest import ApiException


class TestDataSourceApi(unittest.TestCase):
    """DataSourceApi unit test stubs"""

    def setUp(self):
        self.api = api.data_source_api.DataSourceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_data_source_create_v2(self):
        """Test case for data_source_create_v2

        Create a data source.  # noqa: E501
        """
        pass

    def test_data_source_delete_v2(self):
        """Test case for data_source_delete_v2

        Delete a specific data source.  # noqa: E501
        """
        pass

    def test_data_source_get_artifact_v2(self):
        """Test case for data_source_get_artifact_v2

        Get data source artifacts according to its ID.  # noqa: E501
        """
        pass

    def test_data_source_get_v2(self):
        """Test case for data_source_get_v2

        Get a data source according to its ID.  # noqa: E501
        """
        pass

    def test_data_source_list_v2(self):
        """Test case for data_source_list_v2

        Get all data sources.  # noqa: E501
        """
        pass

    def test_data_source_update_v3(self):
        """Test case for data_source_update_v3

        Update a data source.  # noqa: E501
        """
        pass

    def test_edge_get_datasources_v2(self):
        """Test case for edge_get_datasources_v2

        Get all data sources associated with an edge.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CloudProfileProjectUsage(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data_pipeline_ids': 'list[str]',
        'project_id': 'str'
    }

    attribute_map = {
        'data_pipeline_ids': 'dataPipelineIds',
        'project_id': 'projectId'
    }

    def __init__(self, data_pipeline_ids=None, project_id=None):  # noqa: E501
        """CloudProfileProjectUsage - a model defined in Swagger"""  # noqa: E501
        self._data_pipeline_ids = None
        self._project_id = None
        self.discriminator = None
        self.data_pipeline_ids = data_pipeline_ids
        self.project_id = project_id

    @property
    def data_pipeline_ids(self):
        """Gets the data_pipeline_ids of this CloudProfileProjectUsage.  # noqa: E501

        IDs of data pipelines in the project that uses the cloud profile  # noqa: E501

        :return: The data_pipeline_ids of this CloudProfileProjectUsage.  # noqa: E501
        :rtype: list[str]
        """
        return self._data_pipeline_ids

    @data_pipeline_ids.setter
    def data_pipeline_ids(self, data_pipeline_ids):
        """Sets the data_pipeline_ids of this CloudProfileProjectUsage.

        IDs of data pipelines in the project that uses the cloud profile  # noqa: E501

        :param data_pipeline_ids: The data_pipeline_ids of this CloudProfileProjectUsage.  # noqa: E501
        :type: list[str]
        """
        if data_pipeline_ids is None:
            raise ValueError("Invalid value for `data_pipeline_ids`, must not be `None`")  # noqa: E501

        self._data_pipeline_ids = data_pipeline_ids

    @property
    def project_id(self):
        """Gets the project_id of this CloudProfileProjectUsage.  # noqa: E501

        ID of the project  # noqa: E501

        :return: The project_id of this CloudProfileProjectUsage.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this CloudProfileProjectUsage.

        ID of the project  # noqa: E501

        :param project_id: The project_id of this CloudProfileProjectUsage.  # noqa: E501
        :type: str
        """
        if project_id is None:
            raise ValueError("Invalid value for `project_id`, must not be `None`")  # noqa: E501

        self._project_id = project_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CloudProfileProjectUsage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CloudProfileProjectUsage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.iter8_criteria_detail import Iter8CriteriaDetail  # noqa: F401,E501
from kps_api.models.iter8_experiment_item import Iter8ExperimentItem  # noqa: F401,E501
from kps_api.models.iter8_traffic_control import Iter8TrafficControl  # noqa: F401,E501
from kps_api.models.resource_permissions import ResourcePermissions  # noqa: F401,E501


class Iter8ExperimentDetail(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'criterias': 'list[Iter8CriteriaDetail]',
        'experiment_item': 'Iter8ExperimentItem',
        'permissions': 'ResourcePermissions',
        'traffic_control': 'Iter8TrafficControl'
    }

    attribute_map = {
        'criterias': 'criterias',
        'experiment_item': 'experimentItem',
        'permissions': 'permissions',
        'traffic_control': 'trafficControl'
    }

    def __init__(self, criterias=None, experiment_item=None, permissions=None, traffic_control=None):  # noqa: E501
        """Iter8ExperimentDetail - a model defined in Swagger"""  # noqa: E501
        self._criterias = None
        self._experiment_item = None
        self._permissions = None
        self._traffic_control = None
        self.discriminator = None
        if criterias is not None:
            self.criterias = criterias
        if experiment_item is not None:
            self.experiment_item = experiment_item
        if permissions is not None:
            self.permissions = permissions
        if traffic_control is not None:
            self.traffic_control = traffic_control

    @property
    def criterias(self):
        """Gets the criterias of this Iter8ExperimentDetail.  # noqa: E501


        :return: The criterias of this Iter8ExperimentDetail.  # noqa: E501
        :rtype: list[Iter8CriteriaDetail]
        """
        return self._criterias

    @criterias.setter
    def criterias(self, criterias):
        """Sets the criterias of this Iter8ExperimentDetail.


        :param criterias: The criterias of this Iter8ExperimentDetail.  # noqa: E501
        :type: list[Iter8CriteriaDetail]
        """

        self._criterias = criterias

    @property
    def experiment_item(self):
        """Gets the experiment_item of this Iter8ExperimentDetail.  # noqa: E501


        :return: The experiment_item of this Iter8ExperimentDetail.  # noqa: E501
        :rtype: Iter8ExperimentItem
        """
        return self._experiment_item

    @experiment_item.setter
    def experiment_item(self, experiment_item):
        """Sets the experiment_item of this Iter8ExperimentDetail.


        :param experiment_item: The experiment_item of this Iter8ExperimentDetail.  # noqa: E501
        :type: Iter8ExperimentItem
        """

        self._experiment_item = experiment_item

    @property
    def permissions(self):
        """Gets the permissions of this Iter8ExperimentDetail.  # noqa: E501


        :return: The permissions of this Iter8ExperimentDetail.  # noqa: E501
        :rtype: ResourcePermissions
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this Iter8ExperimentDetail.


        :param permissions: The permissions of this Iter8ExperimentDetail.  # noqa: E501
        :type: ResourcePermissions
        """

        self._permissions = permissions

    @property
    def traffic_control(self):
        """Gets the traffic_control of this Iter8ExperimentDetail.  # noqa: E501


        :return: The traffic_control of this Iter8ExperimentDetail.  # noqa: E501
        :rtype: Iter8TrafficControl
        """
        return self._traffic_control

    @traffic_control.setter
    def traffic_control(self, traffic_control):
        """Sets the traffic_control of this Iter8ExperimentDetail.


        :param traffic_control: The traffic_control of this Iter8ExperimentDetail.  # noqa: E501
        :type: Iter8TrafficControl
        """

        self._traffic_control = traffic_control

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Iter8ExperimentDetail, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Iter8ExperimentDetail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.script_param import ScriptParam  # noqa: F401,E501


class Function(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'code': 'str',
        'description': 'str',
        'environment': 'str',
        'id': 'str',
        'language': 'str',
        'name': 'str',
        'params': 'list[ScriptParam]',
        'project_id': 'str',
        'runtime_id': 'str',
        'runtime_tag': 'str',
        'type': 'str'
    }

    attribute_map = {
        'code': 'code',
        'description': 'description',
        'environment': 'environment',
        'id': 'id',
        'language': 'language',
        'name': 'name',
        'params': 'params',
        'project_id': 'projectId',
        'runtime_id': 'runtimeId',
        'runtime_tag': 'runtimeTag',
        'type': 'type'
    }

    def __init__(self, code=None, description=None, environment=None, id=None, language=None, name=None, params=None, project_id=None, runtime_id=None, runtime_tag=None, type=None):  # noqa: E501
        """Function - a model defined in Swagger"""  # noqa: E501
        self._code = None
        self._description = None
        self._environment = None
        self._id = None
        self._language = None
        self._name = None
        self._params = None
        self._project_id = None
        self._runtime_id = None
        self._runtime_tag = None
        self._type = None
        self.discriminator = None
        self.code = code
        if description is not None:
            self.description = description
        self.environment = environment
        if id is not None:
            self.id = id
        self.language = language
        self.name = name
        self.params = params
        if project_id is not None:
            self.project_id = project_id
        if runtime_id is not None:
            self.runtime_id = runtime_id
        if runtime_tag is not None:
            self.runtime_tag = runtime_tag
        self.type = type

    @property
    def code(self):
        """Gets the code of this Function.  # noqa: E501

        The source code for the function script.  # noqa: E501

        :return: The code of this Function.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this Function.

        The source code for the function script.  # noqa: E501

        :param code: The code of this Function.  # noqa: E501
        :type: str
        """
        if code is None:
            raise ValueError("Invalid value for `code`, must not be `None`")  # noqa: E501

        self._code = code

    @property
    def description(self):
        """Gets the description of this Function.  # noqa: E501

        Provide a description for your function code/script.  # noqa: E501

        :return: The description of this Function.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Function.

        Provide a description for your function code/script.  # noqa: E501

        :param description: The description of this Function.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def environment(self):
        """Gets the environment of this Function.  # noqa: E501

        Runtime environment for the function code/script.  # noqa: E501

        :return: The environment of this Function.  # noqa: E501
        :rtype: str
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """Sets the environment of this Function.

        Runtime environment for the function code/script.  # noqa: E501

        :param environment: The environment of this Function.  # noqa: E501
        :type: str
        """
        if environment is None:
            raise ValueError("Invalid value for `environment`, must not be `None`")  # noqa: E501

        self._environment = environment

    @property
    def id(self):
        """Gets the id of this Function.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this Function.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Function.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this Function.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def language(self):
        """Gets the language of this Function.  # noqa: E501

        Programming language for the function code/script. Supported languages are python and javascript  # noqa: E501

        :return: The language of this Function.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this Function.

        Programming language for the function code/script. Supported languages are python and javascript  # noqa: E501

        :param language: The language of this Function.  # noqa: E501
        :type: str
        """
        if language is None:
            raise ValueError("Invalid value for `language`, must not be `None`")  # noqa: E501

        self._language = language

    @property
    def name(self):
        """Gets the name of this Function.  # noqa: E501

        Function name.  # noqa: E501

        :return: The name of this Function.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Function.

        Function name.  # noqa: E501

        :param name: The name of this Function.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def params(self):
        """Gets the params of this Function.  # noqa: E501

        Array of script parameters.  # noqa: E501

        :return: The params of this Function.  # noqa: E501
        :rtype: list[ScriptParam]
        """
        return self._params

    @params.setter
    def params(self, params):
        """Sets the params of this Function.

        Array of script parameters.  # noqa: E501

        :param params: The params of this Function.  # noqa: E501
        :type: list[ScriptParam]
        """
        if params is None:
            raise ValueError("Invalid value for `params`, must not be `None`")  # noqa: E501

        self._params = params

    @property
    def project_id(self):
        """Gets the project_id of this Function.  # noqa: E501

        ID of parent project, required for custom (non-builtin) scripts.  # noqa: E501

        :return: The project_id of this Function.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this Function.

        ID of parent project, required for custom (non-builtin) scripts.  # noqa: E501

        :param project_id: The project_id of this Function.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def runtime_id(self):
        """Gets the runtime_id of this Function.  # noqa: E501

        ID of the ScriptRuntime to use to run this script  # noqa: E501

        :return: The runtime_id of this Function.  # noqa: E501
        :rtype: str
        """
        return self._runtime_id

    @runtime_id.setter
    def runtime_id(self, runtime_id):
        """Sets the runtime_id of this Function.

        ID of the ScriptRuntime to use to run this script  # noqa: E501

        :param runtime_id: The runtime_id of this Function.  # noqa: E501
        :type: str
        """

        self._runtime_id = runtime_id

    @property
    def runtime_tag(self):
        """Gets the runtime_tag of this Function.  # noqa: E501

        Docker image tag of the ScriptRuntime to use to run this script. If missing or empty, then backend should treat it as \"latest\"  # noqa: E501

        :return: The runtime_tag of this Function.  # noqa: E501
        :rtype: str
        """
        return self._runtime_tag

    @runtime_tag.setter
    def runtime_tag(self, runtime_tag):
        """Sets the runtime_tag of this Function.

        Docker image tag of the ScriptRuntime to use to run this script. If missing or empty, then backend should treat it as \"latest\"  # noqa: E501

        :param runtime_tag: The runtime_tag of this Function.  # noqa: E501
        :type: str
        """

        self._runtime_tag = runtime_tag

    @property
    def type(self):
        """Gets the type of this Function.  # noqa: E501

        Type of function code/script: Transformation or Function. Transformation takes a data stream as input and produces a different data stream as output. Function takes a data stream as input but has no constraint on output.  # noqa: E501

        :return: The type of this Function.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Function.

        Type of function code/script: Transformation or Function. Transformation takes a data stream as input and produces a different data stream as output. Function takes a data stream as input but has no constraint on output.  # noqa: E501

        :param type: The type of this Function.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["Transformation", "Function"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Function, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Function):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.data_source_field_info_v2 import DataSourceFieldInfoV2  # noqa: F401,E501
from kps_api.models.data_source_field_selector import DataSourceFieldSelector  # noqa: F401,E501
from kps_api.models.data_source_ifc_info import DataSourceIfcInfo  # noqa: F401,E501


class DataSourceV2(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'auth_type': 'str',
        'edge_id': 'str',
        'fields': 'list[DataSourceFieldInfoV2]',
        'id': 'str',
        'ifc_info': 'DataSourceIfcInfo',
        'name': 'str',
        'protocol': 'str',
        'selectors': 'list[DataSourceFieldSelector]',
        'type': 'str'
    }

    attribute_map = {
        'auth_type': 'authType',
        'edge_id': 'edgeId',
        'fields': 'fields',
        'id': 'id',
        'ifc_info': 'ifcInfo',
        'name': 'name',
        'protocol': 'protocol',
        'selectors': 'selectors',
        'type': 'type'
    }

    def __init__(self, auth_type=None, edge_id=None, fields=None, id=None, ifc_info=None, name=None, protocol=None, selectors=None, type=None):  # noqa: E501
        """DataSourceV2 - a model defined in Swagger"""  # noqa: E501
        self._auth_type = None
        self._edge_id = None
        self._fields = None
        self._id = None
        self._ifc_info = None
        self._name = None
        self._protocol = None
        self._selectors = None
        self._type = None
        self.discriminator = None
        self.auth_type = auth_type
        self.edge_id = edge_id
        self.fields = fields
        if id is not None:
            self.id = id
        if ifc_info is not None:
            self.ifc_info = ifc_info
        self.name = name
        self.protocol = protocol
        self.selectors = selectors
        self.type = type

    @property
    def auth_type(self):
        """Gets the auth_type of this DataSourceV2.  # noqa: E501

        Type of authentication used by sensor  # noqa: E501

        :return: The auth_type of this DataSourceV2.  # noqa: E501
        :rtype: str
        """
        return self._auth_type

    @auth_type.setter
    def auth_type(self, auth_type):
        """Sets the auth_type of this DataSourceV2.

        Type of authentication used by sensor  # noqa: E501

        :param auth_type: The auth_type of this DataSourceV2.  # noqa: E501
        :type: str
        """
        if auth_type is None:
            raise ValueError("Invalid value for `auth_type`, must not be `None`")  # noqa: E501
        allowed_values = ["CERTIFICATE", "PASSWORD", "TOKEN"]  # noqa: E501
        if auth_type not in allowed_values:
            raise ValueError(
                "Invalid value for `auth_type` ({0}), must be one of {1}"  # noqa: E501
                .format(auth_type, allowed_values)
            )

        self._auth_type = auth_type

    @property
    def edge_id(self):
        """Gets the edge_id of this DataSourceV2.  # noqa: E501

        ID of the edge this entity belongs to  # noqa: E501

        :return: The edge_id of this DataSourceV2.  # noqa: E501
        :rtype: str
        """
        return self._edge_id

    @edge_id.setter
    def edge_id(self, edge_id):
        """Sets the edge_id of this DataSourceV2.

        ID of the edge this entity belongs to  # noqa: E501

        :param edge_id: The edge_id of this DataSourceV2.  # noqa: E501
        :type: str
        """
        if edge_id is None:
            raise ValueError("Invalid value for `edge_id`, must not be `None`")  # noqa: E501

        self._edge_id = edge_id

    @property
    def fields(self):
        """Gets the fields of this DataSourceV2.  # noqa: E501

        User defined fields to extract data from the topic payload.  # noqa: E501

        :return: The fields of this DataSourceV2.  # noqa: E501
        :rtype: list[DataSourceFieldInfoV2]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this DataSourceV2.

        User defined fields to extract data from the topic payload.  # noqa: E501

        :param fields: The fields of this DataSourceV2.  # noqa: E501
        :type: list[DataSourceFieldInfoV2]
        """
        if fields is None:
            raise ValueError("Invalid value for `fields`, must not be `None`")  # noqa: E501

        self._fields = fields

    @property
    def id(self):
        """Gets the id of this DataSourceV2.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this DataSourceV2.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DataSourceV2.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this DataSourceV2.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def ifc_info(self):
        """Gets the ifc_info of this DataSourceV2.  # noqa: E501


        :return: The ifc_info of this DataSourceV2.  # noqa: E501
        :rtype: DataSourceIfcInfo
        """
        return self._ifc_info

    @ifc_info.setter
    def ifc_info(self, ifc_info):
        """Sets the ifc_info of this DataSourceV2.


        :param ifc_info: The ifc_info of this DataSourceV2.  # noqa: E501
        :type: DataSourceIfcInfo
        """

        self._ifc_info = ifc_info

    @property
    def name(self):
        """Gets the name of this DataSourceV2.  # noqa: E501


        :return: The name of this DataSourceV2.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DataSourceV2.


        :param name: The name of this DataSourceV2.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def protocol(self):
        """Gets the protocol of this DataSourceV2.  # noqa: E501

        Sensor protocol  # noqa: E501

        :return: The protocol of this DataSourceV2.  # noqa: E501
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this DataSourceV2.

        Sensor protocol  # noqa: E501

        :param protocol: The protocol of this DataSourceV2.  # noqa: E501
        :type: str
        """
        if protocol is None:
            raise ValueError("Invalid value for `protocol`, must not be `None`")  # noqa: E501
        allowed_values = ["MQTT", "RTSP", "GIGEVISION", "OTHER", "DATAINTERFACE"]  # noqa: E501
        if protocol not in allowed_values:
            raise ValueError(
                "Invalid value for `protocol` ({0}), must be one of {1}"  # noqa: E501
                .format(protocol, allowed_values)
            )

        self._protocol = protocol

    @property
    def selectors(self):
        """Gets the selectors of this DataSourceV2.  # noqa: E501

        A list of DataSourceFieldSelector users assigned to the data source. Allows a user to use Category selectors to identify the data pipeline source. Selectors with different category IDs are combined with the AND operator, while selectors with the same category ID are combined with the OR operator.  # noqa: E501

        :return: The selectors of this DataSourceV2.  # noqa: E501
        :rtype: list[DataSourceFieldSelector]
        """
        return self._selectors

    @selectors.setter
    def selectors(self, selectors):
        """Sets the selectors of this DataSourceV2.

        A list of DataSourceFieldSelector users assigned to the data source. Allows a user to use Category selectors to identify the data pipeline source. Selectors with different category IDs are combined with the AND operator, while selectors with the same category ID are combined with the OR operator.  # noqa: E501

        :param selectors: The selectors of this DataSourceV2.  # noqa: E501
        :type: list[DataSourceFieldSelector]
        """
        if selectors is None:
            raise ValueError("Invalid value for `selectors`, must not be `None`")  # noqa: E501

        self._selectors = selectors

    @property
    def type(self):
        """Gets the type of this DataSourceV2.  # noqa: E501

        Type of data source. Sensor or Gateway  # noqa: E501

        :return: The type of this DataSourceV2.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DataSourceV2.

        Type of data source. Sensor or Gateway  # noqa: E501

        :param type: The type of this DataSourceV2.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["Sensor", "Gateway"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DataSourceV2, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DataSourceV2):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ResourcePermissions(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'create': 'bool',
        'delete': 'bool',
        'update': 'bool'
    }

    attribute_map = {
        'create': 'create',
        'delete': 'delete',
        'update': 'update'
    }

    def __init__(self, create=None, delete=None, update=None):  # noqa: E501
        """ResourcePermissions - a model defined in Swagger"""  # noqa: E501
        self._create = None
        self._delete = None
        self._update = None
        self.discriminator = None
        if create is not None:
            self.create = create
        if delete is not None:
            self.delete = delete
        if update is not None:
            self.update = update

    @property
    def create(self):
        """Gets the create of this ResourcePermissions.  # noqa: E501


        :return: The create of this ResourcePermissions.  # noqa: E501
        :rtype: bool
        """
        return self._create

    @create.setter
    def create(self, create):
        """Sets the create of this ResourcePermissions.


        :param create: The create of this ResourcePermissions.  # noqa: E501
        :type: bool
        """

        self._create = create

    @property
    def delete(self):
        """Gets the delete of this ResourcePermissions.  # noqa: E501


        :return: The delete of this ResourcePermissions.  # noqa: E501
        :rtype: bool
        """
        return self._delete

    @delete.setter
    def delete(self, delete):
        """Sets the delete of this ResourcePermissions.


        :param delete: The delete of this ResourcePermissions.  # noqa: E501
        :type: bool
        """

        self._delete = delete

    @property
    def update(self):
        """Gets the update of this ResourcePermissions.  # noqa: E501


        :return: The update of this ResourcePermissions.  # noqa: E501
        :rtype: bool
        """
        return self._update

    @update.setter
    def update(self, update):
        """Sets the update of this ResourcePermissions.


        :param update: The update of this ResourcePermissions.  # noqa: E501
        :type: bool
        """

        self._update = update

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResourcePermissions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourcePermissions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.log_collector_api import LogCollectorApi  # noqa: E501
from kps_api.rest import ApiException


class TestLogCollectorApi(unittest.TestCase):
    """LogCollectorApi unit test stubs"""

    def setUp(self):
        self.api = api.log_collector_api.LogCollectorApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_log_collector_create(self):
        """Test case for log_collector_create

        Create a log collector.  # noqa: E501
        """
        pass

    def test_log_collector_delete(self):
        """Test case for log_collector_delete

        Delete a log collector.  # noqa: E501
        """
        pass

    def test_log_collector_get(self):
        """Test case for log_collector_get

        Get information about log collector  # noqa: E501
        """
        pass

    def test_log_collector_start(self):
        """Test case for log_collector_start

        Start a log collector.  # noqa: E501
        """
        pass

    def test_log_collector_stop(self):
        """Test case for log_collector_stop

        Stop a log collector.  # noqa: E501
        """
        pass

    def test_log_collector_update(self):
        """Test case for log_collector_update

        Update a log collector.  # noqa: E501
        """
        pass

    def test_log_collectors_list(self):
        """Test case for log_collectors_list

        Get configured log collectors in a system.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ClusterRbacConfigSpec(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'exclusion': 'object',
        'inclusion': 'object',
        'mode': 'object'
    }

    attribute_map = {
        'exclusion': 'exclusion',
        'inclusion': 'inclusion',
        'mode': 'mode'
    }

    def __init__(self, exclusion=None, inclusion=None, mode=None):  # noqa: E501
        """ClusterRbacConfigSpec - a model defined in Swagger"""  # noqa: E501
        self._exclusion = None
        self._inclusion = None
        self._mode = None
        self.discriminator = None
        if exclusion is not None:
            self.exclusion = exclusion
        if inclusion is not None:
            self.inclusion = inclusion
        if mode is not None:
            self.mode = mode

    @property
    def exclusion(self):
        """Gets the exclusion of this ClusterRbacConfigSpec.  # noqa: E501


        :return: The exclusion of this ClusterRbacConfigSpec.  # noqa: E501
        :rtype: object
        """
        return self._exclusion

    @exclusion.setter
    def exclusion(self, exclusion):
        """Sets the exclusion of this ClusterRbacConfigSpec.


        :param exclusion: The exclusion of this ClusterRbacConfigSpec.  # noqa: E501
        :type: object
        """

        self._exclusion = exclusion

    @property
    def inclusion(self):
        """Gets the inclusion of this ClusterRbacConfigSpec.  # noqa: E501


        :return: The inclusion of this ClusterRbacConfigSpec.  # noqa: E501
        :rtype: object
        """
        return self._inclusion

    @inclusion.setter
    def inclusion(self, inclusion):
        """Sets the inclusion of this ClusterRbacConfigSpec.


        :param inclusion: The inclusion of this ClusterRbacConfigSpec.  # noqa: E501
        :type: object
        """

        self._inclusion = inclusion

    @property
    def mode(self):
        """Gets the mode of this ClusterRbacConfigSpec.  # noqa: E501


        :return: The mode of this ClusterRbacConfigSpec.  # noqa: E501
        :rtype: object
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this ClusterRbacConfigSpec.


        :param mode: The mode of this ClusterRbacConfigSpec.  # noqa: E501
        :type: object
        """

        self._mode = mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ClusterRbacConfigSpec, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClusterRbacConfigSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.category_info import CategoryInfo  # noqa: F401,E501
from kps_api.models.node_role import NodeRole  # noqa: F401,E501


class EdgeV2(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'connected': 'bool',
        'description': 'str',
        'edge_devices': 'float',
        'gateway': 'str',
        'id': 'str',
        'ip_address': 'str',
        'labels': 'list[CategoryInfo]',
        'name': 'str',
        'role': 'NodeRole',
        'serial_number': 'str',
        'short_id': 'str',
        'subnet': 'str',
        'type': 'str'
    }

    attribute_map = {
        'connected': 'connected',
        'description': 'description',
        'edge_devices': 'edgeDevices',
        'gateway': 'gateway',
        'id': 'id',
        'ip_address': 'ipAddress',
        'labels': 'labels',
        'name': 'name',
        'role': 'role',
        'serial_number': 'serialNumber',
        'short_id': 'shortId',
        'subnet': 'subnet',
        'type': 'type'
    }

    def __init__(self, connected=None, description=None, edge_devices=None, gateway=None, id=None, ip_address=None, labels=None, name=None, role=None, serial_number=None, short_id=None, subnet=None, type=None):  # noqa: E501
        """EdgeV2 - a model defined in Swagger"""  # noqa: E501
        self._connected = None
        self._description = None
        self._edge_devices = None
        self._gateway = None
        self._id = None
        self._ip_address = None
        self._labels = None
        self._name = None
        self._role = None
        self._serial_number = None
        self._short_id = None
        self._subnet = None
        self._type = None
        self.discriminator = None
        if connected is not None:
            self.connected = connected
        if description is not None:
            self.description = description
        self.edge_devices = edge_devices
        self.gateway = gateway
        if id is not None:
            self.id = id
        self.ip_address = ip_address
        if labels is not None:
            self.labels = labels
        self.name = name
        if role is not None:
            self.role = role
        self.serial_number = serial_number
        if short_id is not None:
            self.short_id = short_id
        self.subnet = subnet
        if type is not None:
            self.type = type

    @property
    def connected(self):
        """Gets the connected of this EdgeV2.  # noqa: E501

        Determines if the edge is currently connected to XI IoT management services.  # noqa: E501

        :return: The connected of this EdgeV2.  # noqa: E501
        :rtype: bool
        """
        return self._connected

    @connected.setter
    def connected(self, connected):
        """Sets the connected of this EdgeV2.

        Determines if the edge is currently connected to XI IoT management services.  # noqa: E501

        :param connected: The connected of this EdgeV2.  # noqa: E501
        :type: bool
        """

        self._connected = connected

    @property
    def description(self):
        """Gets the description of this EdgeV2.  # noqa: E501

        Edge description  # noqa: E501

        :return: The description of this EdgeV2.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this EdgeV2.

        Edge description  # noqa: E501

        :param description: The description of this EdgeV2.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def edge_devices(self):
        """Gets the edge_devices of this EdgeV2.  # noqa: E501

        Number of devices (nodes) in this edge  # noqa: E501

        :return: The edge_devices of this EdgeV2.  # noqa: E501
        :rtype: float
        """
        return self._edge_devices

    @edge_devices.setter
    def edge_devices(self, edge_devices):
        """Sets the edge_devices of this EdgeV2.

        Number of devices (nodes) in this edge  # noqa: E501

        :param edge_devices: The edge_devices of this EdgeV2.  # noqa: E501
        :type: float
        """
        if edge_devices is None:
            raise ValueError("Invalid value for `edge_devices`, must not be `None`")  # noqa: E501

        self._edge_devices = edge_devices

    @property
    def gateway(self):
        """Gets the gateway of this EdgeV2.  # noqa: E501

        Edge Gateway IP address  # noqa: E501

        :return: The gateway of this EdgeV2.  # noqa: E501
        :rtype: str
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """Sets the gateway of this EdgeV2.

        Edge Gateway IP address  # noqa: E501

        :param gateway: The gateway of this EdgeV2.  # noqa: E501
        :type: str
        """
        if gateway is None:
            raise ValueError("Invalid value for `gateway`, must not be `None`")  # noqa: E501

        self._gateway = gateway

    @property
    def id(self):
        """Gets the id of this EdgeV2.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this EdgeV2.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EdgeV2.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this EdgeV2.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def ip_address(self):
        """Gets the ip_address of this EdgeV2.  # noqa: E501

        Edge IP Address  # noqa: E501

        :return: The ip_address of this EdgeV2.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this EdgeV2.

        Edge IP Address  # noqa: E501

        :param ip_address: The ip_address of this EdgeV2.  # noqa: E501
        :type: str
        """
        if ip_address is None:
            raise ValueError("Invalid value for `ip_address`, must not be `None`")  # noqa: E501

        self._ip_address = ip_address

    @property
    def labels(self):
        """Gets the labels of this EdgeV2.  # noqa: E501

        A list of Category labels for this edge.  # noqa: E501

        :return: The labels of this EdgeV2.  # noqa: E501
        :rtype: list[CategoryInfo]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this EdgeV2.

        A list of Category labels for this edge.  # noqa: E501

        :param labels: The labels of this EdgeV2.  # noqa: E501
        :type: list[CategoryInfo]
        """

        self._labels = labels

    @property
    def name(self):
        """Gets the name of this EdgeV2.  # noqa: E501

        Edge name. Maximum length edge name is determined by kubernetes. Name length limited to 60 as node name is the edge name plus a suffix. https://github.com/kubernetes/kubernetes/blob/master/staging/src/k8s.io/apimachinery/pkg/util/validation/validation.go  # noqa: E501

        :return: The name of this EdgeV2.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this EdgeV2.

        Edge name. Maximum length edge name is determined by kubernetes. Name length limited to 60 as node name is the edge name plus a suffix. https://github.com/kubernetes/kubernetes/blob/master/staging/src/k8s.io/apimachinery/pkg/util/validation/validation.go  # noqa: E501

        :param name: The name of this EdgeV2.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def role(self):
        """Gets the role of this EdgeV2.  # noqa: E501


        :return: The role of this EdgeV2.  # noqa: E501
        :rtype: NodeRole
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this EdgeV2.


        :param role: The role of this EdgeV2.  # noqa: E501
        :type: NodeRole
        """

        self._role = role

    @property
    def serial_number(self):
        """Gets the serial_number of this EdgeV2.  # noqa: E501

        Edge serial number  # noqa: E501

        :return: The serial_number of this EdgeV2.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this EdgeV2.

        Edge serial number  # noqa: E501

        :param serial_number: The serial_number of this EdgeV2.  # noqa: E501
        :type: str
        """
        if serial_number is None:
            raise ValueError("Invalid value for `serial_number`, must not be `None`")  # noqa: E501

        self._serial_number = serial_number

    @property
    def short_id(self):
        """Gets the short_id of this EdgeV2.  # noqa: E501

        ShortID is the unique ID for the given edge. This ID must be unique for each edge, for the given tenant.  # noqa: E501

        :return: The short_id of this EdgeV2.  # noqa: E501
        :rtype: str
        """
        return self._short_id

    @short_id.setter
    def short_id(self, short_id):
        """Sets the short_id of this EdgeV2.

        ShortID is the unique ID for the given edge. This ID must be unique for each edge, for the given tenant.  # noqa: E501

        :param short_id: The short_id of this EdgeV2.  # noqa: E501
        :type: str
        """

        self._short_id = short_id

    @property
    def subnet(self):
        """Gets the subnet of this EdgeV2.  # noqa: E501

        Edge subnet mask  # noqa: E501

        :return: The subnet of this EdgeV2.  # noqa: E501
        :rtype: str
        """
        return self._subnet

    @subnet.setter
    def subnet(self, subnet):
        """Sets the subnet of this EdgeV2.

        Edge subnet mask  # noqa: E501

        :param subnet: The subnet of this EdgeV2.  # noqa: E501
        :type: str
        """
        if subnet is None:
            raise ValueError("Invalid value for `subnet`, must not be `None`")  # noqa: E501

        self._subnet = subnet

    @property
    def type(self):
        """Gets the type of this EdgeV2.  # noqa: E501

        Type of edge.  # noqa: E501

        :return: The type of this EdgeV2.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this EdgeV2.

        Type of edge.  # noqa: E501

        :param type: The type of this EdgeV2.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EdgeV2, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EdgeV2):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.http_service_proxy_api import HTTPServiceProxyApi  # noqa: E501
from kps_api.rest import ApiException


class TestHTTPServiceProxyApi(unittest.TestCase):
    """HTTPServiceProxyApi unit test stubs"""

    def setUp(self):
        self.api = api.http_service_proxy_api.HTTPServiceProxyApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_h_ttp_service_proxy_create(self):
        """Test case for h_ttp_service_proxy_create

        Create a HTTP service proxy.  # noqa: E501
        """
        pass

    def test_h_ttp_service_proxy_delete(self):
        """Test case for h_ttp_service_proxy_delete

        Delete HTTP service proxy.  # noqa: E501
        """
        pass

    def test_h_ttp_service_proxy_get(self):
        """Test case for h_ttp_service_proxy_get

        Get a HTTP service proxy by its ID.  # noqa: E501
        """
        pass

    def test_h_ttp_service_proxy_list(self):
        """Test case for h_ttp_service_proxy_list

        Get all HTTP service proxies.  # noqa: E501
        """
        pass

    def test_h_ttp_service_proxy_update(self):
        """Test case for h_ttp_service_proxy_update

        Update a HTTP service proxy by its ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.pod_metrics import PodMetrics  # noqa: F401,E501
from kps_api.models.pod_status import PodStatus  # noqa: F401,E501


class AppStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'image_list': 'list[str]',
        'pod_metrics_list': 'list[PodMetrics]',
        'pod_status_list': 'list[PodStatus]'
    }

    attribute_map = {
        'image_list': 'imageList',
        'pod_metrics_list': 'podMetricsList',
        'pod_status_list': 'podStatusList'
    }

    def __init__(self, image_list=None, pod_metrics_list=None, pod_status_list=None):  # noqa: E501
        """AppStatus - a model defined in Swagger"""  # noqa: E501
        self._image_list = None
        self._pod_metrics_list = None
        self._pod_status_list = None
        self.discriminator = None
        if image_list is not None:
            self.image_list = image_list
        if pod_metrics_list is not None:
            self.pod_metrics_list = pod_metrics_list
        self.pod_status_list = pod_status_list

    @property
    def image_list(self):
        """Gets the image_list of this AppStatus.  # noqa: E501


        :return: The image_list of this AppStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._image_list

    @image_list.setter
    def image_list(self, image_list):
        """Sets the image_list of this AppStatus.


        :param image_list: The image_list of this AppStatus.  # noqa: E501
        :type: list[str]
        """

        self._image_list = image_list

    @property
    def pod_metrics_list(self):
        """Gets the pod_metrics_list of this AppStatus.  # noqa: E501


        :return: The pod_metrics_list of this AppStatus.  # noqa: E501
        :rtype: list[PodMetrics]
        """
        return self._pod_metrics_list

    @pod_metrics_list.setter
    def pod_metrics_list(self, pod_metrics_list):
        """Sets the pod_metrics_list of this AppStatus.


        :param pod_metrics_list: The pod_metrics_list of this AppStatus.  # noqa: E501
        :type: list[PodMetrics]
        """

        self._pod_metrics_list = pod_metrics_list

    @property
    def pod_status_list(self):
        """Gets the pod_status_list of this AppStatus.  # noqa: E501


        :return: The pod_status_list of this AppStatus.  # noqa: E501
        :rtype: list[PodStatus]
        """
        return self._pod_status_list

    @pod_status_list.setter
    def pod_status_list(self, pod_status_list):
        """Sets the pod_status_list of this AppStatus.


        :param pod_status_list: The pod_status_list of this AppStatus.  # noqa: E501
        :type: list[PodStatus]
        """
        if pod_status_list is None:
            raise ValueError("Invalid value for `pod_status_list`, must not be `None`")  # noqa: E501

        self._pod_status_list = pod_status_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AppStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AppStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class UserApiToken(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'active': 'bool',
        'created_at': 'datetime',
        'id': 'str',
        'updated_at': 'datetime',
        'used_at': 'datetime',
        'user_id': 'str'
    }

    attribute_map = {
        'active': 'active',
        'created_at': 'createdAt',
        'id': 'id',
        'updated_at': 'updatedAt',
        'used_at': 'usedAt',
        'user_id': 'userId'
    }

    def __init__(self, active=None, created_at=None, id=None, updated_at=None, used_at=None, user_id=None):  # noqa: E501
        """UserApiToken - a model defined in Swagger"""  # noqa: E501
        self._active = None
        self._created_at = None
        self._id = None
        self._updated_at = None
        self._used_at = None
        self._user_id = None
        self.discriminator = None
        self.active = active
        if created_at is not None:
            self.created_at = created_at
        if id is not None:
            self.id = id
        if updated_at is not None:
            self.updated_at = updated_at
        if used_at is not None:
            self.used_at = used_at
        self.user_id = user_id

    @property
    def active(self):
        """Gets the active of this UserApiToken.  # noqa: E501

        Whether the token is active  # noqa: E501

        :return: The active of this UserApiToken.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this UserApiToken.

        Whether the token is active  # noqa: E501

        :param active: The active of this UserApiToken.  # noqa: E501
        :type: bool
        """
        if active is None:
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def created_at(self):
        """Gets the created_at of this UserApiToken.  # noqa: E501

        created at timestamp  # noqa: E501

        :return: The created_at of this UserApiToken.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this UserApiToken.

        created at timestamp  # noqa: E501

        :param created_at: The created_at of this UserApiToken.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def id(self):
        """Gets the id of this UserApiToken.  # noqa: E501

        ID of the user API token  # noqa: E501

        :return: The id of this UserApiToken.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserApiToken.

        ID of the user API token  # noqa: E501

        :param id: The id of this UserApiToken.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def updated_at(self):
        """Gets the updated_at of this UserApiToken.  # noqa: E501

        updated at timestamp  # noqa: E501

        :return: The updated_at of this UserApiToken.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this UserApiToken.

        updated at timestamp  # noqa: E501

        :param updated_at: The updated_at of this UserApiToken.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def used_at(self):
        """Gets the used_at of this UserApiToken.  # noqa: E501

        last used timestamp  # noqa: E501

        :return: The used_at of this UserApiToken.  # noqa: E501
        :rtype: datetime
        """
        return self._used_at

    @used_at.setter
    def used_at(self, used_at):
        """Sets the used_at of this UserApiToken.

        last used timestamp  # noqa: E501

        :param used_at: The used_at of this UserApiToken.  # noqa: E501
        :type: datetime
        """

        self._used_at = used_at

    @property
    def user_id(self):
        """Gets the user_id of this UserApiToken.  # noqa: E501

        User ID  # noqa: E501

        :return: The user_id of this UserApiToken.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this UserApiToken.

        User ID  # noqa: E501

        :param user_id: The user_id of this UserApiToken.  # noqa: E501
        :type: str
        """
        if user_id is None:
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserApiToken, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserApiToken):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from kps_api.api_client import ApiClient


class ApplicationApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def application_create_v2(self, body, authorization, **kwargs):  # noqa: E501
        """Create an application.  # noqa: E501

        Create an application.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.application_create_v2(body, authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ApplicationV2 body: Describes the application creation request. (required)
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :return: CreateDocumentResponseV2
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.application_create_v2_with_http_info(body, authorization, **kwargs)  # noqa: E501
        else:
            (data) = self.application_create_v2_with_http_info(body, authorization, **kwargs)  # noqa: E501
            return data

    def application_create_v2_with_http_info(self, body, authorization, **kwargs):  # noqa: E501
        """Create an application.  # noqa: E501

        Create an application.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.application_create_v2_with_http_info(body, authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ApplicationV2 body: Describes the application creation request. (required)
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :return: CreateDocumentResponseV2
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'authorization']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method application_create_v2" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `application_create_v2`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `application_create_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/v1.0/applications', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateDocumentResponseV2',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def application_delete_v2(self, authorization, id, **kwargs):  # noqa: E501
        """Delete application specified by the application ID.  # noqa: E501

        Deletes the application with the given ID {id}.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.application_delete_v2(authorization, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :param str id: ID of the entity (required)
        :return: DeleteDocumentResponseV2
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.application_delete_v2_with_http_info(authorization, id, **kwargs)  # noqa: E501
        else:
            (data) = self.application_delete_v2_with_http_info(authorization, id, **kwargs)  # noqa: E501
            return data

    def application_delete_v2_with_http_info(self, authorization, id, **kwargs):  # noqa: E501
        """Delete application specified by the application ID.  # noqa: E501

        Deletes the application with the given ID {id}.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.application_delete_v2_with_http_info(authorization, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :param str id: ID of the entity (required)
        :return: DeleteDocumentResponseV2
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method application_delete_v2" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `application_delete_v2`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `application_delete_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/v1.0/applications/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteDocumentResponseV2',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def application_get_v2(self, authorization, id, **kwargs):  # noqa: E501
        """Get application by application ID.  # noqa: E501

        Retrieves the application with the given ID {id}.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.application_get_v2(authorization, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :param str id: ID of the entity (required)
        :return: ApplicationV2
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.application_get_v2_with_http_info(authorization, id, **kwargs)  # noqa: E501
        else:
            (data) = self.application_get_v2_with_http_info(authorization, id, **kwargs)  # noqa: E501
            return data

    def application_get_v2_with_http_info(self, authorization, id, **kwargs):  # noqa: E501
        """Get application by application ID.  # noqa: E501

        Retrieves the application with the given ID {id}.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.application_get_v2_with_http_info(authorization, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :param str id: ID of the entity (required)
        :return: ApplicationV2
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method application_get_v2" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `application_get_v2`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `application_get_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/v1.0/applications/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApplicationV2',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def application_list_v2(self, authorization, **kwargs):  # noqa: E501
        """Get all applications.  # noqa: E501

        Retrieves a list of all applications.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.application_list_v2(authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :param int page_index: 0-based index of the page to fetch results.
        :param int page_size: Item count of each page.
        :param list[str] order_by: Specify result order. Zero or more entries with format: &ltkey> [desc] where orderByKeys lists allowed keys in each response.
        :param str filter: Specify result filter. Format is similar to a SQL WHERE clause. For example, to filter object by name with prefix foo, use: name LIKE 'foo%'. Supported filter keys are the same as order by keys.
        :return: ApplicationListResponsePayload
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.application_list_v2_with_http_info(authorization, **kwargs)  # noqa: E501
        else:
            (data) = self.application_list_v2_with_http_info(authorization, **kwargs)  # noqa: E501
            return data

    def application_list_v2_with_http_info(self, authorization, **kwargs):  # noqa: E501
        """Get all applications.  # noqa: E501

        Retrieves a list of all applications.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.application_list_v2_with_http_info(authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :param int page_index: 0-based index of the page to fetch results.
        :param int page_size: Item count of each page.
        :param list[str] order_by: Specify result order. Zero or more entries with format: &ltkey> [desc] where orderByKeys lists allowed keys in each response.
        :param str filter: Specify result filter. Format is similar to a SQL WHERE clause. For example, to filter object by name with prefix foo, use: name LIKE 'foo%'. Supported filter keys are the same as order by keys.
        :return: ApplicationListResponsePayload
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'page_index', 'page_size', 'order_by', 'filter']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method application_list_v2" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `application_list_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_index' in params:
            query_params.append(('pageIndex', params['page_index']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('orderBy', params['order_by']))  # noqa: E501
            collection_formats['orderBy'] = 'csv'  # noqa: E501
        if 'filter' in params:
            query_params.append(('filter', params['filter']))  # noqa: E501

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/v1.0/applications', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApplicationListResponsePayload',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def application_update_v3(self, body, authorization, id, **kwargs):  # noqa: E501
        """Update a specific application with ID {id}.  # noqa: E501

        Update a specific application with ID {id}. You cannot change the project associated with the application or the application ID. You can change all other attributes.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.application_update_v3(body, authorization, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ApplicationV2 body: (required)
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :param str id: ID of the entity (required)
        :return: UpdateDocumentResponseV2
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.application_update_v3_with_http_info(body, authorization, id, **kwargs)  # noqa: E501
        else:
            (data) = self.application_update_v3_with_http_info(body, authorization, id, **kwargs)  # noqa: E501
            return data

    def application_update_v3_with_http_info(self, body, authorization, id, **kwargs):  # noqa: E501
        """Update a specific application with ID {id}.  # noqa: E501

        Update a specific application with ID {id}. You cannot change the project associated with the application or the application ID. You can change all other attributes.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.application_update_v3_with_http_info(body, authorization, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ApplicationV2 body: (required)
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :param str id: ID of the entity (required)
        :return: UpdateDocumentResponseV2
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'authorization', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method application_update_v3" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `application_update_v3`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `application_update_v3`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `application_update_v3`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/v1.0/applications/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdateDocumentResponseV2',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_application_containers(self, authorization, id, edge_id, **kwargs):  # noqa: E501
        """Get containers of an application specified by Application ID running on a specific edge.  # noqa: E501

        Gets the containers of an application with the given ID {id} running on edge with id {edgeId}.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_application_containers(authorization, id, edge_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :param str id: ID of the entity (required)
        :param str edge_id: ID for the edge (required)
        :return: ApplicationContainers
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_application_containers_with_http_info(authorization, id, edge_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_application_containers_with_http_info(authorization, id, edge_id, **kwargs)  # noqa: E501
            return data

    def get_application_containers_with_http_info(self, authorization, id, edge_id, **kwargs):  # noqa: E501
        """Get containers of an application specified by Application ID running on a specific edge.  # noqa: E501

        Gets the containers of an application with the given ID {id} running on edge with id {edgeId}.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_application_containers_with_http_info(authorization, id, edge_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :param str id: ID of the entity (required)
        :param str edge_id: ID for the edge (required)
        :return: ApplicationContainers
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'id', 'edge_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_application_containers" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `get_application_containers`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_application_containers`")  # noqa: E501
        # verify the required parameter 'edge_id' is set
        if ('edge_id' not in params or
                params['edge_id'] is None):
            raise ValueError("Missing the required parameter `edge_id` when calling `get_application_containers`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501
        if 'edge_id' in params:
            path_params['edgeId'] = params['edge_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/v1.0/applications/{id}/containers/{edgeId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApplicationContainers',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def project_get_applications_v2(self, authorization, project_id, **kwargs):  # noqa: E501
        """Get all applications in a project according to project ID.  # noqa: E501

        Retrieves a list of all applications in a project with ID {projectId}.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_get_applications_v2(authorization, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :param str project_id: ID for the project (required)
        :param int page_index: 0-based index of the page to fetch results.
        :param int page_size: Item count of each page.
        :param list[str] order_by: Specify result order. Zero or more entries with format: &ltkey> [desc] where orderByKeys lists allowed keys in each response.
        :param str filter: Specify result filter. Format is similar to a SQL WHERE clause. For example, to filter object by name with prefix foo, use: name LIKE 'foo%'. Supported filter keys are the same as order by keys.
        :return: ApplicationListResponsePayload
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.project_get_applications_v2_with_http_info(authorization, project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.project_get_applications_v2_with_http_info(authorization, project_id, **kwargs)  # noqa: E501
            return data

    def project_get_applications_v2_with_http_info(self, authorization, project_id, **kwargs):  # noqa: E501
        """Get all applications in a project according to project ID.  # noqa: E501

        Retrieves a list of all applications in a project with ID {projectId}.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.project_get_applications_v2_with_http_info(authorization, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :param str project_id: ID for the project (required)
        :param int page_index: 0-based index of the page to fetch results.
        :param int page_size: Item count of each page.
        :param list[str] order_by: Specify result order. Zero or more entries with format: &ltkey> [desc] where orderByKeys lists allowed keys in each response.
        :param str filter: Specify result filter. Format is similar to a SQL WHERE clause. For example, to filter object by name with prefix foo, use: name LIKE 'foo%'. Supported filter keys are the same as order by keys.
        :return: ApplicationListResponsePayload
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'project_id', 'page_index', 'page_size', 'order_by', 'filter']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method project_get_applications_v2" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `project_get_applications_v2`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `project_get_applications_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []
        if 'page_index' in params:
            query_params.append(('pageIndex', params['page_index']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('orderBy', params['order_by']))  # noqa: E501
            collection_formats['orderBy'] = 'csv'  # noqa: E501
        if 'filter' in params:
            query_params.append(('filter', params['filter']))  # noqa: E501

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/v1.0/projects/{projectId}/applications', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApplicationListResponsePayload',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.ml_model_version import MLModelVersion  # noqa: F401,E501


class MLModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'framework_type': 'str',
        'id': 'str',
        'model_versions': 'list[MLModelVersion]',
        'name': 'str',
        'project_id': 'str'
    }

    attribute_map = {
        'description': 'description',
        'framework_type': 'frameworkType',
        'id': 'id',
        'model_versions': 'modelVersions',
        'name': 'name',
        'project_id': 'projectId'
    }

    def __init__(self, description=None, framework_type=None, id=None, model_versions=None, name=None, project_id=None):  # noqa: E501
        """MLModel - a model defined in Swagger"""  # noqa: E501
        self._description = None
        self._framework_type = None
        self._id = None
        self._model_versions = None
        self._name = None
        self._project_id = None
        self.discriminator = None
        self.description = description
        self.framework_type = framework_type
        if id is not None:
            self.id = id
        if model_versions is not None:
            self.model_versions = model_versions
        self.name = name
        self.project_id = project_id

    @property
    def description(self):
        """Gets the description of this MLModel.  # noqa: E501

        Describe the machine learning model.  Maximum length is 200 characters.  # noqa: E501

        :return: The description of this MLModel.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this MLModel.

        Describe the machine learning model.  Maximum length is 200 characters.  # noqa: E501

        :param description: The description of this MLModel.  # noqa: E501
        :type: str
        """
        if description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def framework_type(self):
        """Gets the framework_type of this MLModel.  # noqa: E501

        Machine learning model framework type.  # noqa: E501

        :return: The framework_type of this MLModel.  # noqa: E501
        :rtype: str
        """
        return self._framework_type

    @framework_type.setter
    def framework_type(self, framework_type):
        """Sets the framework_type of this MLModel.

        Machine learning model framework type.  # noqa: E501

        :param framework_type: The framework_type of this MLModel.  # noqa: E501
        :type: str
        """
        if framework_type is None:
            raise ValueError("Invalid value for `framework_type`, must not be `None`")  # noqa: E501
        allowed_values = ["TensorFlow 1.13.1", "OpenVINO 2019_R2", "TensorFlow 2.1.0"]  # noqa: E501
        if framework_type not in allowed_values:
            raise ValueError(
                "Invalid value for `framework_type` ({0}), must be one of {1}"  # noqa: E501
                .format(framework_type, allowed_values)
            )

        self._framework_type = framework_type

    @property
    def id(self):
        """Gets the id of this MLModel.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this MLModel.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MLModel.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this MLModel.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def model_versions(self):
        """Gets the model_versions of this MLModel.  # noqa: E501

        Machine learning model versions.  # noqa: E501

        :return: The model_versions of this MLModel.  # noqa: E501
        :rtype: list[MLModelVersion]
        """
        return self._model_versions

    @model_versions.setter
    def model_versions(self, model_versions):
        """Sets the model_versions of this MLModel.

        Machine learning model versions.  # noqa: E501

        :param model_versions: The model_versions of this MLModel.  # noqa: E501
        :type: list[MLModelVersion]
        """

        self._model_versions = model_versions

    @property
    def name(self):
        """Gets the name of this MLModel.  # noqa: E501

        Name for the machine learning model. Maximum length is 200 characters.  # noqa: E501

        :return: The name of this MLModel.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MLModel.

        Name for the machine learning model. Maximum length is 200 characters.  # noqa: E501

        :param name: The name of this MLModel.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def project_id(self):
        """Gets the project_id of this MLModel.  # noqa: E501

        Parent project ID associated with this machine learning model.  # noqa: E501

        :return: The project_id of this MLModel.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this MLModel.

        Parent project ID associated with this machine learning model.  # noqa: E501

        :param project_id: The project_id of this MLModel.  # noqa: E501
        :type: str
        """
        if project_id is None:
            raise ValueError("Invalid value for `project_id`, must not be `None`")  # noqa: E501

        self._project_id = project_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MLModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MLModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AuditLog(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'datetime',
        'edge_ids': 'str',
        'hostname': 'str',
        'request_header': 'str',
        'request_id': 'str',
        'request_method': 'str',
        'request_payload': 'str',
        'request_url': 'str',
        'response_code': 'int',
        'response_length': 'int',
        'response_message': 'str',
        'started_at': 'datetime',
        'tenant_id': 'str',
        'time_ms': 'float',
        'user_email': 'str'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'edge_ids': 'edgeIds',
        'hostname': 'hostname',
        'request_header': 'requestHeader',
        'request_id': 'requestId',
        'request_method': 'requestMethod',
        'request_payload': 'requestPayload',
        'request_url': 'requestUrl',
        'response_code': 'responseCode',
        'response_length': 'responseLength',
        'response_message': 'responseMessage',
        'started_at': 'startedAt',
        'tenant_id': 'tenantId',
        'time_ms': 'timeMs',
        'user_email': 'userEmail'
    }

    def __init__(self, created_at=None, edge_ids=None, hostname=None, request_header=None, request_id=None, request_method=None, request_payload=None, request_url=None, response_code=None, response_length=None, response_message=None, started_at=None, tenant_id=None, time_ms=None, user_email=None):  # noqa: E501
        """AuditLog - a model defined in Swagger"""  # noqa: E501
        self._created_at = None
        self._edge_ids = None
        self._hostname = None
        self._request_header = None
        self._request_id = None
        self._request_method = None
        self._request_payload = None
        self._request_url = None
        self._response_code = None
        self._response_length = None
        self._response_message = None
        self._started_at = None
        self._tenant_id = None
        self._time_ms = None
        self._user_email = None
        self.discriminator = None
        if created_at is not None:
            self.created_at = created_at
        if edge_ids is not None:
            self.edge_ids = edge_ids
        if hostname is not None:
            self.hostname = hostname
        if request_header is not None:
            self.request_header = request_header
        if request_id is not None:
            self.request_id = request_id
        if request_method is not None:
            self.request_method = request_method
        if request_payload is not None:
            self.request_payload = request_payload
        if request_url is not None:
            self.request_url = request_url
        if response_code is not None:
            self.response_code = response_code
        if response_length is not None:
            self.response_length = response_length
        if response_message is not None:
            self.response_message = response_message
        if started_at is not None:
            self.started_at = started_at
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if time_ms is not None:
            self.time_ms = time_ms
        if user_email is not None:
            self.user_email = user_email

    @property
    def created_at(self):
        """Gets the created_at of this AuditLog.  # noqa: E501


        :return: The created_at of this AuditLog.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this AuditLog.


        :param created_at: The created_at of this AuditLog.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def edge_ids(self):
        """Gets the edge_ids of this AuditLog.  # noqa: E501


        :return: The edge_ids of this AuditLog.  # noqa: E501
        :rtype: str
        """
        return self._edge_ids

    @edge_ids.setter
    def edge_ids(self, edge_ids):
        """Sets the edge_ids of this AuditLog.


        :param edge_ids: The edge_ids of this AuditLog.  # noqa: E501
        :type: str
        """

        self._edge_ids = edge_ids

    @property
    def hostname(self):
        """Gets the hostname of this AuditLog.  # noqa: E501


        :return: The hostname of this AuditLog.  # noqa: E501
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """Sets the hostname of this AuditLog.


        :param hostname: The hostname of this AuditLog.  # noqa: E501
        :type: str
        """

        self._hostname = hostname

    @property
    def request_header(self):
        """Gets the request_header of this AuditLog.  # noqa: E501


        :return: The request_header of this AuditLog.  # noqa: E501
        :rtype: str
        """
        return self._request_header

    @request_header.setter
    def request_header(self, request_header):
        """Sets the request_header of this AuditLog.


        :param request_header: The request_header of this AuditLog.  # noqa: E501
        :type: str
        """

        self._request_header = request_header

    @property
    def request_id(self):
        """Gets the request_id of this AuditLog.  # noqa: E501


        :return: The request_id of this AuditLog.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this AuditLog.


        :param request_id: The request_id of this AuditLog.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    @property
    def request_method(self):
        """Gets the request_method of this AuditLog.  # noqa: E501


        :return: The request_method of this AuditLog.  # noqa: E501
        :rtype: str
        """
        return self._request_method

    @request_method.setter
    def request_method(self, request_method):
        """Sets the request_method of this AuditLog.


        :param request_method: The request_method of this AuditLog.  # noqa: E501
        :type: str
        """

        self._request_method = request_method

    @property
    def request_payload(self):
        """Gets the request_payload of this AuditLog.  # noqa: E501


        :return: The request_payload of this AuditLog.  # noqa: E501
        :rtype: str
        """
        return self._request_payload

    @request_payload.setter
    def request_payload(self, request_payload):
        """Sets the request_payload of this AuditLog.


        :param request_payload: The request_payload of this AuditLog.  # noqa: E501
        :type: str
        """

        self._request_payload = request_payload

    @property
    def request_url(self):
        """Gets the request_url of this AuditLog.  # noqa: E501


        :return: The request_url of this AuditLog.  # noqa: E501
        :rtype: str
        """
        return self._request_url

    @request_url.setter
    def request_url(self, request_url):
        """Sets the request_url of this AuditLog.


        :param request_url: The request_url of this AuditLog.  # noqa: E501
        :type: str
        """

        self._request_url = request_url

    @property
    def response_code(self):
        """Gets the response_code of this AuditLog.  # noqa: E501


        :return: The response_code of this AuditLog.  # noqa: E501
        :rtype: int
        """
        return self._response_code

    @response_code.setter
    def response_code(self, response_code):
        """Sets the response_code of this AuditLog.


        :param response_code: The response_code of this AuditLog.  # noqa: E501
        :type: int
        """

        self._response_code = response_code

    @property
    def response_length(self):
        """Gets the response_length of this AuditLog.  # noqa: E501


        :return: The response_length of this AuditLog.  # noqa: E501
        :rtype: int
        """
        return self._response_length

    @response_length.setter
    def response_length(self, response_length):
        """Sets the response_length of this AuditLog.


        :param response_length: The response_length of this AuditLog.  # noqa: E501
        :type: int
        """

        self._response_length = response_length

    @property
    def response_message(self):
        """Gets the response_message of this AuditLog.  # noqa: E501


        :return: The response_message of this AuditLog.  # noqa: E501
        :rtype: str
        """
        return self._response_message

    @response_message.setter
    def response_message(self, response_message):
        """Sets the response_message of this AuditLog.


        :param response_message: The response_message of this AuditLog.  # noqa: E501
        :type: str
        """

        self._response_message = response_message

    @property
    def started_at(self):
        """Gets the started_at of this AuditLog.  # noqa: E501


        :return: The started_at of this AuditLog.  # noqa: E501
        :rtype: datetime
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Sets the started_at of this AuditLog.


        :param started_at: The started_at of this AuditLog.  # noqa: E501
        :type: datetime
        """

        self._started_at = started_at

    @property
    def tenant_id(self):
        """Gets the tenant_id of this AuditLog.  # noqa: E501


        :return: The tenant_id of this AuditLog.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this AuditLog.


        :param tenant_id: The tenant_id of this AuditLog.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def time_ms(self):
        """Gets the time_ms of this AuditLog.  # noqa: E501


        :return: The time_ms of this AuditLog.  # noqa: E501
        :rtype: float
        """
        return self._time_ms

    @time_ms.setter
    def time_ms(self, time_ms):
        """Sets the time_ms of this AuditLog.


        :param time_ms: The time_ms of this AuditLog.  # noqa: E501
        :type: float
        """

        self._time_ms = time_ms

    @property
    def user_email(self):
        """Gets the user_email of this AuditLog.  # noqa: E501


        :return: The user_email of this AuditLog.  # noqa: E501
        :rtype: str
        """
        return self._user_email

    @user_email.setter
    def user_email(self, user_email):
        """Sets the user_email of this AuditLog.


        :param user_email: The user_email of this AuditLog.  # noqa: E501
        :type: str
        """

        self._user_email = user_email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AuditLog, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuditLog):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class EventFilter(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end_time': 'datetime',
        'keys': 'dict(str, str)',
        'path': 'str',
        'size': 'int',
        'start': 'int',
        'start_time': 'datetime'
    }

    attribute_map = {
        'end_time': 'endTime',
        'keys': 'keys',
        'path': 'path',
        'size': 'size',
        'start': 'start',
        'start_time': 'startTime'
    }

    def __init__(self, end_time=None, keys=None, path=None, size=None, start=None, start_time=None):  # noqa: E501
        """EventFilter - a model defined in Swagger"""  # noqa: E501
        self._end_time = None
        self._keys = None
        self._path = None
        self._size = None
        self._start = None
        self._start_time = None
        self.discriminator = None
        if end_time is not None:
            self.end_time = end_time
        if keys is not None:
            self.keys = keys
        self.path = path
        if size is not None:
            self.size = size
        if start is not None:
            self.start = start
        if start_time is not None:
            self.start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this EventFilter.  # noqa: E501


        :return: The end_time of this EventFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this EventFilter.


        :param end_time: The end_time of this EventFilter.  # noqa: E501
        :type: datetime
        """

        self._end_time = end_time

    @property
    def keys(self):
        """Gets the keys of this EventFilter.  # noqa: E501


        :return: The keys of this EventFilter.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._keys

    @keys.setter
    def keys(self, keys):
        """Sets the keys of this EventFilter.


        :param keys: The keys of this EventFilter.  # noqa: E501
        :type: dict(str, str)
        """

        self._keys = keys

    @property
    def path(self):
        """Gets the path of this EventFilter.  # noqa: E501


        :return: The path of this EventFilter.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this EventFilter.


        :param path: The path of this EventFilter.  # noqa: E501
        :type: str
        """
        if path is None:
            raise ValueError("Invalid value for `path`, must not be `None`")  # noqa: E501

        self._path = path

    @property
    def size(self):
        """Gets the size of this EventFilter.  # noqa: E501


        :return: The size of this EventFilter.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this EventFilter.


        :param size: The size of this EventFilter.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def start(self):
        """Gets the start of this EventFilter.  # noqa: E501


        :return: The start of this EventFilter.  # noqa: E501
        :rtype: int
        """
        return self._start

    @start.setter
    def start(self, start):
        """Sets the start of this EventFilter.


        :param start: The start of this EventFilter.  # noqa: E501
        :type: int
        """

        self._start = start

    @property
    def start_time(self):
        """Gets the start_time of this EventFilter.  # noqa: E501


        :return: The start_time of this EventFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this EventFilter.


        :param start_time: The start_time of this EventFilter.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EventFilter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
